var Level = {
    
    game_running: false,
    
    collision_objects: [],
    
    planet_objects: [],
    
    level_container: new PIXI.Container(),
    
    collision_explosion: null,
    
    scroll_position_x: 0,
    scroll_position_y: 0,
    scroll_area: 400,
    
    addPlanet: function(planet) {
        this.planet_objects.push(planet);
        this.level_container.addChild(planet.sprite);
        // We can collide with a planet
        this.addCollisionObject(planet);
    },
    
    addCollisionObject: function(collision_object) {
        this.collision_objects.push(collision_object);
    },
    
    set: function(level, stage) {
        // Clear stage
        stage.removeChildren();
        
        // Clear level
        this.level_container.removeChildren();
        this.level_container.setTransform(0,0);

        // Place spaceship
        Spaceship.reset(500,500);
        this.level_container.addChild(Spaceship.sprite);
        
        // Clear collision objects
        this.collision_objects = [];
        
        // Ready collision explosion
        this.collision_explosion = new Explosion();
        this.level_container.addChild(this.collision_explosion.sprite);

        switch(level) {
            case 1:
                // Render level one
                var planet = new Planet(6, 700, 700);
                this.addPlanet(planet);
            //    break;

                var planet = new Planet(4, 200, 200);
                this.addPlanet(planet);
                var planet = new Planet(5, 1400, 400);
                this.addPlanet(planet);
                var planet = new Planet(7, 2000, 560);
                this.addPlanet(planet);
                break;
        }
        
        stage.addChild(this.level_container);
        
        this.game_running = true;
    },
    
    simulate: function(delta) {
        if (! this.game_running) return;
        this.collision_detector();
        this.gravity_logic(delta);
        this.level_scroller(delta);
    },
    
    gravity_logic: function(delta) {
        this.planet_objects.forEach(function(planet) {
            planet.getGravityPull(Spaceship.sprite.x, Spaceship.sprite.y);
        }.bind(this));
    },
    
    level_scroller: function(delta) {
        var global_position = Spaceship.sprite.getGlobalPosition();
        
        if (global_position.x < this.scroll_area) {
            // We need to scroll left
            this.scroll_position_x -= this.scroll_area-global_position.x;
        } else if (global_position.x > $(window).innerWidth()-this.scroll_area) {
            // We need to scroll right
            this.scroll_position_x += this.scroll_area-($(window).innerWidth()-global_position.x);
        }
        
        if (global_position.y < this.scroll_area) {
            // We need to scroll left
            this.scroll_position_y -= this.scroll_area-global_position.y;
        } else if (global_position.y > $(window).innerHeight()-this.scroll_area) {
            // We need to scroll right
            this.scroll_position_y += this.scroll_area-($(window).innerHeight()-global_position.y);
        }
        
        // Move level
        this.level_container.setTransform(-this.scroll_position_x, -this.scroll_position_y);
    },
    
    collision_detector: function() {
        this.collision_objects.forEach(function(v) {
            var dist = distance(Spaceship.sprite.x, Spaceship.sprite.y, v.sprite.x, v.sprite.y);
            if (dist < v.diameter/2+25) {
                this.game_running = false;
                Spaceship.sprite.visible = false;
                this.collision_explosion.explode(Spaceship.sprite.x, Spaceship.sprite.y);
                return;
            }
        }.bind(this));
    }
}